@@ -79,7 +79,7 @@ show_version_cb (const char *option_name,
                  gpointer data,
                  GError **error)
 {
-	g_print ("%s %s\n", _("GNOME bug-buddy"), VERSION);
+	g_print ("%s %s\n", _("GNOME Bug Buddy"), VERSION);
 
 	exit (EXIT_SUCCESS);
 
@@ -458,7 +458,7 @@ network_error (SoupMessage *msg, GtkBuilder *ui)
 						      GTK_DIALOG_MODAL,
 						      GTK_MESSAGE_WARNING,
 						      GTK_BUTTONS_YES_NO,
-						      _("There has been a network error while sending the report. "
+						      _("There was a network error while sending the report. "
 							"Do you want to save this report and send it later?"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  "%s", _("Please ensure that your Internet connection is active "
@@ -603,7 +603,7 @@ bug_sent (SoupSession *session, SoupMessage *msg, GtkBuilder *ui)
 		g_free (text);
 		save_email (gtk_entry_get_text (GTK_ENTRY (gtk_builder_get_object (ui, "email-entry"))));
 	} else {
-		errmsg = _("Bug Buddy has encountered an error while submitting your report "
+		errmsg = _("Bug Buddy encountered an error while submitting your report "
 		           "to the Bugzilla server.  Details of the error are included below.\n\n");
 
 		if (err && err->domain == SOUP_XMLRPC_FAULT) {
@@ -641,12 +641,12 @@ bug_sent (SoupSession *session, SoupMessage *msg, GtkBuilder *ui)
 				                        err->message);
 				break;
 			case BUGZILLA_ERROR_RECV_PARSE_FAILED:
-				text = g_strdup_printf (_("Failed to parse the xml-rpc response.  Response follows:\n\n%s"), 
+				text = g_strdup_printf (_("Failed to parse the XML-RPC response.  Response follows:\n\n%s"),
 				                        err->message);
 				break;
 			default:
 				text = g_strdup_printf (_("An unknown error occurred.  This is most likely a problem with "
-				                          "bug-buddy. Please report this problem manually at bugzilla."
+				                          "Bug Buddy. Please report this problem manually at bugzilla."
 			                                  "gnome.org\n\n"));
 				break;
 			}
@@ -863,7 +863,7 @@ send_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version, GtkBuild
 	g_free (final_text);
 
 	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (gtk_builder_get_object (ui, "progressbar")),
-				   _("Sending..."));
+				   _("Sending…"));
 
 }
 
@@ -1410,7 +1410,7 @@ unknown_app_finished (GtkBuilder *ui)
 
 	label_text = g_markup_printf_escaped (_("The application %s has crashed.\n"
 			      "Information about the crash has been successfully collected.\n\n"
-	                      "This application is not known to bug-buddy, therefore the "
+	                      "This application is not known to Bug Buddy, therefore the "
 	                      "bug report cannot be sent to the GNOME Bugzilla.  Please save the "
 	                      "bug to a text file and report it to the appropriate bug tracker "
 	                      "for this application."), gopt_data.app_file);
@@ -1958,7 +1958,7 @@ main (int argc, char *argv[])
 	progress = g_timeout_add (100, update_progress_bar,
 				  gtk_builder_get_object (ui, "progressbar"));
 	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (gtk_builder_get_object (ui, "progressbar")),
-				   _("Collecting information from your system..."));
+				   _("Collecting information from your system…"));
 
 	if (gopt_data.app_file == NULL && gopt_data.package == NULL) {
 		buddy_error (NULL, _("Either --appname or --package arguments are required.\n"));	
@@ -1973,7 +1973,7 @@ main (int argc, char *argv[])
 	}
 
 	if (gopt_data.own_file == TRUE && gopt_data.include_file == NULL) {
-		buddy_error (NULL, _("The --unlink-tempfile option needs a --include argument.\n"));
+		buddy_error (NULL, _("The --unlink-tempfile option needs an --include argument.\n"));
 		return 0;
 	}
 	
@@ -2019,7 +2019,7 @@ main (int argc, char *argv[])
 		}
 
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (gtk_builder_get_object (ui, "progressbar")),
-					   _("Collecting information from the crash..."));
+					   _("Collecting information from the crash…"));
 
 		fill_system_info (ui);
 		
@@ -2086,9 +2086,9 @@ main (int argc, char *argv[])
 		gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (ui, "progressbar")));
 
 		lang_note = gettext (en_lang_note);
-		msg = g_strconcat (_("Thank you for helping us improving our software.\n"
-				     "Please fill your suggestions/error information for %s application.\n\n"
-				     "A valid email address is required.  This will allow developers to "
+		msg = g_strconcat (_("Thank you for helping us to improve our software.\n"
+				     "Please fill in your suggestions/error information for %s application.\n\n"
+				     "A valid email address is required. This will allow developers to "
 				     "contact you for more information if necessary."),
 				   strcmp (lang_note, en_lang_note)? lang_note: NULL,
 				   NULL);
